==> openshift-model-machine-6.8.0-sources.jar: io/fabric8/openshift/api/model/machine/v1alpha1/SubnetFilterFluent.java <==
package io.fabric8.openshift.api.model.machine.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SubnetFilterFluent<A extends SubnetFilterFluent<A>> extends BaseFluent<A>{
  public SubnetFilterFluent() {
  }
  public SubnetFilterFluent(SubnetFilter instance) {
    instance = (instance != null ? instance : new SubnetFilter());

    if (instance != null) {
      this.withCidr(instance.getCidr());
      this.withDescription(instance.getDescription());
      this.withEnableDhcp(instance.getEnableDhcp());
      this.withGatewayIp(instance.getGatewayIp());
      this.withId(instance.getId());
      this.withIpVersion(instance.getIpVersion());
      this.withIpv6AddressMode(instance.getIpv6AddressMode());
      this.withIpv6RaMode(instance.getIpv6RaMode());
      this.withLimit(instance.getLimit());
      this.withMarker(instance.getMarker());
      this.withName(instance.getName());
      this.withNetworkId(instance.getNetworkId());
      this.withNotTags(instance.getNotTags());
      this.withNotTagsAny(instance.getNotTagsAny());
      this.withProjectId(instance.getProjectId());
      this.withSortDir(instance.getSortDir());
      this.withSortKey(instance.getSortKey());
      this.withSubnetpoolId(instance.getSubnetpoolId());
      this.withTags(instance.getTags());
      this.withTagsAny(instance.getTagsAny());
      this.withTenantId(instance.getTenantId());
      this.withCidr(instance.getCidr());
      this.withDescription(instance.getDescription());
      this.withEnableDhcp(instance.getEnableDhcp());
      this.withGatewayIp(instance.getGatewayIp());
      this.withId(instance.getId());
      this.withIpVersion(instance.getIpVersion());
      this.withIpv6AddressMode(instance.getIpv6AddressMode());
      this.withIpv6RaMode(instance.getIpv6RaMode());
      this.withLimit(instance.getLimit());
      this.withMarker(instance.getMarker());
      this.withName(instance.getName());
      this.withNetworkId(instance.getNetworkId());
      this.withNotTags(instance.getNotTags());
      this.withNotTagsAny(instance.getNotTagsAny());
      this.withProjectId(instance.getProjectId());
      this.withSortDir(instance.getSortDir());
      this.withSortKey(instance.getSortKey());
      this.withSubnetpoolId(instance.getSubnetpoolId());
      this.withTags(instance.getTags());
      this.withTagsAny(instance.getTagsAny());
      this.withTenantId(instance.getTenantId());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String cidr;
  private String description;
  private Boolean enableDhcp;
  private String gatewayIp;
  private String id;
  private Integer ipVersion;
  private String ipv6AddressMode;
  private String ipv6RaMode;
  private Integer limit;
  private String marker;
  private String name;
  private String networkId;
  private String notTags;
  private String notTagsAny;
  private String projectId;
  private String sortDir;
  private String sortKey;
  private String subnetpoolId;
  private String tags;
  private String tagsAny;
  private String tenantId;
  private Map<String,Object> additionalProperties;
  public String getCidr() {
    return this.cidr;
  }
  public A withCidr(String cidr) {
    this.cidr=cidr; return (A) this;
  }
  public boolean hasCidr() {
    return this.cidr != null;
  }
  public String getDescription() {
    return this.description;
  }
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  public boolean hasDescription() {
    return this.description != null;
  }
  public Boolean getEnableDhcp() {
    return this.enableDhcp;
  }
  public A withEnableDhcp(Boolean enableDhcp) {
    this.enableDhcp=enableDhcp; return (A) this;
  }
  public boolean hasEnableDhcp() {
    return this.enableDhcp != null;
  }
  public String getGatewayIp() {
    return this.gatewayIp;
  }
  public A withGatewayIp(String gatewayIp) {
    this.gatewayIp=gatewayIp; return (A) this;
  }
  public boolean hasGatewayIp() {
    return this.gatewayIp != null;
  }
  public String getId() {
    return this.id;
  }
  public A withId(String id) {
    this.id=id; return (A) this;
  }
  public boolean hasId() {
    return this.id != null;
  }
  public Integer getIpVersion() {
    return this.ipVersion;
  }
  public A withIpVersion(Integer ipVersion) {
    this.ipVersion=ipVersion; return (A) this;
  }
  public boolean hasIpVersion() {
    return this.ipVersion != null;
  }
  public String getIpv6AddressMode() {
    return this.ipv6AddressMode;
  }
  public A withIpv6AddressMode(String ipv6AddressMode) {
    this.ipv6AddressMode=ipv6AddressMode; return (A) this;
  }
  public boolean hasIpv6AddressMode() {
    return this.ipv6AddressMode != null;
  }
  public String getIpv6RaMode() {
    return this.ipv6RaMode;
  }
  public A withIpv6RaMode(String ipv6RaMode) {
    this.ipv6RaMode=ipv6RaMode; return (A) this;
  }
  public boolean hasIpv6RaMode() {
    return this.ipv6RaMode != null;
  }
  public Integer getLimit() {
    return this.limit;
  }
  public A withLimit(Integer limit) {
    this.limit=limit; return (A) this;
  }
  public boolean hasLimit() {
    return this.limit != null;
  }
  public String getMarker() {
    return this.marker;
  }
  public A withMarker(String marker) {
    this.marker=marker; return (A) this;
  }
  public boolean hasMarker() {
    return this.marker != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public String getNetworkId() {
    return this.networkId;
  }
  public A withNetworkId(String networkId) {
    this.networkId=networkId; return (A) this;
  }
  public boolean hasNetworkId() {
    return this.networkId != null;
  }
  public String getNotTags() {
    return this.notTags;
  }
  public A withNotTags(String notTags) {
    this.notTags=notTags; return (A) this;
  }
  public boolean hasNotTags() {
    return this.notTags != null;
  }
  public String getNotTagsAny() {
    return this.notTagsAny;
  }
  public A withNotTagsAny(String notTagsAny) {
    this.notTagsAny=notTagsAny; return (A) this;
  }
  public boolean hasNotTagsAny() {
    return this.notTagsAny != null;
  }
  public String getProjectId() {
    return this.projectId;
  }
  public A withProjectId(String projectId) {
    this.projectId=projectId; return (A) this;
  }
  public boolean hasProjectId() {
    return this.projectId != null;
  }
  public String getSortDir() {
    return this.sortDir;
  }
  public A withSortDir(String sortDir) {
    this.sortDir=sortDir; return (A) this;
  }
  public boolean hasSortDir() {
    return this.sortDir != null;
  }
  public String getSortKey() {
    return this.sortKey;
  }
  public A withSortKey(String sortKey) {
    this.sortKey=sortKey; return (A) this;
  }
  public boolean hasSortKey() {
    return this.sortKey != null;
  }
  public String getSubnetpoolId() {
    return this.subnetpoolId;
  }
  public A withSubnetpoolId(String subnetpoolId) {
    this.subnetpoolId=subnetpoolId; return (A) this;
  }
  public boolean hasSubnetpoolId() {
    return this.subnetpoolId != null;
  }
  public String getTags() {
    return this.tags;
  }
  public A withTags(String tags) {
    this.tags=tags; return (A) this;
  }
  public boolean hasTags() {
    return this.tags != null;
  }
  public String getTagsAny() {
    return this.tagsAny;
  }
  public A withTagsAny(String tagsAny) {
    this.tagsAny=tagsAny; return (A) this;
  }
  public boolean hasTagsAny() {
    return this.tagsAny != null;
  }
  public String getTenantId() {
    return this.tenantId;
  }
  public A withTenantId(String tenantId) {
    this.tenantId=tenantId; return (A) this;
  }
  public boolean hasTenantId() {
    return this.tenantId != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubnetFilterFluent that = (SubnetFilterFluent) o;
    if (!java.util.Objects.equals(cidr, that.cidr)) return false;

    if (!java.util.Objects.equals(description, that.description)) return false;

    if (!java.util.Objects.equals(enableDhcp, that.enableDhcp)) return false;

    if (!java.util.Objects.equals(gatewayIp, that.gatewayIp)) return false;

    if (!java.util.Objects.equals(id, that.id)) return false;

    if (!java.util.Objects.equals(ipVersion, that.ipVersion)) return false;

    if (!java.util.Objects.equals(ipv6AddressMode, that.ipv6AddressMode)) return false;

    if (!java.util.Objects.equals(ipv6RaMode, that.ipv6RaMode)) return false;

    if (!java.util.Objects.equals(limit, that.limit)) return false;

    if (!java.util.Objects.equals(marker, that.marker)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(networkId, that.networkId)) return false;

    if (!java.util.Objects.equals(notTags, that.notTags)) return false;

    if (!java.util.Objects.equals(notTagsAny, that.notTagsAny)) return false;

    if (!java.util.Objects.equals(projectId, that.projectId)) return false;

    if (!java.util.Objects.equals(sortDir, that.sortDir)) return false;

    if (!java.util.Objects.equals(sortKey, that.sortKey)) return false;

    if (!java.util.Objects.equals(subnetpoolId, that.subnetpoolId)) return false;

    if (!java.util.Objects.equals(tags, that.tags)) return false;

    if (!java.util.Objects.equals(tagsAny, that.tagsAny)) return false;

    if (!java.util.Objects.equals(tenantId, that.tenantId)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cidr,  description,  enableDhcp,  gatewayIp,  id,  ipVersion,  ipv6AddressMode,  ipv6RaMode,  limit,  marker,  name,  networkId,  notTags,  notTagsAny,  projectId,  sortDir,  sortKey,  subnetpoolId,  tags,  tagsAny,  tenantId,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cidr != null) { sb.append("cidr:"); sb.append(cidr + ","); }
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (enableDhcp != null) { sb.append("enableDhcp:"); sb.append(enableDhcp + ","); }
    if (gatewayIp != null) { sb.append("gatewayIp:"); sb.append(gatewayIp + ","); }
    if (id != null) { sb.append("id:"); sb.append(id + ","); }
    if (ipVersion != null) { sb.append("ipVersion:"); sb.append(ipVersion + ","); }
    if (ipv6AddressMode != null) { sb.append("ipv6AddressMode:"); sb.append(ipv6AddressMode + ","); }
    if (ipv6RaMode != null) { sb.append("ipv6RaMode:"); sb.append(ipv6RaMode + ","); }
    if (limit != null) { sb.append("limit:"); sb.append(limit + ","); }
    if (marker != null) { sb.append("marker:"); sb.append(marker + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (networkId != null) { sb.append("networkId:"); sb.append(networkId + ","); }
    if (notTags != null) { sb.append("notTags:"); sb.append(notTags + ","); }
    if (notTagsAny != null) { sb.append("notTagsAny:"); sb.append(notTagsAny + ","); }
    if (projectId != null) { sb.append("projectId:"); sb.append(projectId + ","); }
    if (sortDir != null) { sb.append("sortDir:"); sb.append(sortDir + ","); }
    if (sortKey != null) { sb.append("sortKey:"); sb.append(sortKey + ","); }
    if (subnetpoolId != null) { sb.append("subnetpoolId:"); sb.append(subnetpoolId + ","); }
    if (tags != null) { sb.append("tags:"); sb.append(tags + ","); }
    if (tagsAny != null) { sb.append("tagsAny:"); sb.append(tagsAny + ","); }
    if (tenantId != null) { sb.append("tenantId:"); sb.append(tenantId + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withEnableDhcp() {
    return withEnableDhcp(true);
  }
  
}

==> openshift-model-machine-6.9.0-sources.jar: io/fabric8/openshift/api/model/machine/v1alpha1/SubnetFilterFluent.java <==
package io.fabric8.openshift.api.model.machine.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SubnetFilterFluent<A extends SubnetFilterFluent<A>> extends BaseFluent<A>{
  public SubnetFilterFluent() {
  }
  
  public SubnetFilterFluent(SubnetFilter instance) {
    this.copyInstance(instance);
  }
  private String cidr;
  private String description;
  private Boolean enableDhcp;
  private String gatewayIp;
  private String id;
  private Integer ipVersion;
  private String ipv6AddressMode;
  private String ipv6RaMode;
  private Integer limit;
  private String marker;
  private String name;
  private String networkId;
  private String notTags;
  private String notTagsAny;
  private String projectId;
  private String sortDir;
  private String sortKey;
  private String subnetpoolId;
  private String tags;
  private String tagsAny;
  private String tenantId;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(SubnetFilter instance) {
    instance = (instance != null ? instance : new SubnetFilter());
  
    if (instance != null) {
        this.withCidr(instance.getCidr());
        this.withDescription(instance.getDescription());
        this.withEnableDhcp(instance.getEnableDhcp());
        this.withGatewayIp(instance.getGatewayIp());
        this.withId(instance.getId());
        this.withIpVersion(instance.getIpVersion());
        this.withIpv6AddressMode(instance.getIpv6AddressMode());
        this.withIpv6RaMode(instance.getIpv6RaMode());
        this.withLimit(instance.getLimit());
        this.withMarker(instance.getMarker());
        this.withName(instance.getName());
        this.withNetworkId(instance.getNetworkId());
        this.withNotTags(instance.getNotTags());
        this.withNotTagsAny(instance.getNotTagsAny());
        this.withProjectId(instance.getProjectId());
        this.withSortDir(instance.getSortDir());
        this.withSortKey(instance.getSortKey());
        this.withSubnetpoolId(instance.getSubnetpoolId());
        this.withTags(instance.getTags());
        this.withTagsAny(instance.getTagsAny());
        this.withTenantId(instance.getTenantId());
        this.withCidr(instance.getCidr());
        this.withDescription(instance.getDescription());
        this.withEnableDhcp(instance.getEnableDhcp());
        this.withGatewayIp(instance.getGatewayIp());
        this.withId(instance.getId());
        this.withIpVersion(instance.getIpVersion());
        this.withIpv6AddressMode(instance.getIpv6AddressMode());
        this.withIpv6RaMode(instance.getIpv6RaMode());
        this.withLimit(instance.getLimit());
        this.withMarker(instance.getMarker());
        this.withName(instance.getName());
        this.withNetworkId(instance.getNetworkId());
        this.withNotTags(instance.getNotTags());
        this.withNotTagsAny(instance.getNotTagsAny());
        this.withProjectId(instance.getProjectId());
        this.withSortDir(instance.getSortDir());
        this.withSortKey(instance.getSortKey());
        this.withSubnetpoolId(instance.getSubnetpoolId());
        this.withTags(instance.getTags());
        this.withTagsAny(instance.getTagsAny());
        this.withTenantId(instance.getTenantId());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getCidr() {
    return this.cidr;
  }
  
  public A withCidr(String cidr) {
    this.cidr=cidr; return (A) this;
  }
  
  public boolean hasCidr() {
    return this.cidr != null;
  }
  
  public String getDescription() {
    return this.description;
  }
  
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  
  public boolean hasDescription() {
    return this.description != null;
  }
  
  public Boolean getEnableDhcp() {
    return this.enableDhcp;
  }
  
  public A withEnableDhcp(Boolean enableDhcp) {
    this.enableDhcp=enableDhcp; return (A) this;
  }
  
  public boolean hasEnableDhcp() {
    return this.enableDhcp != null;
  }
  
  public String getGatewayIp() {
    return this.gatewayIp;
  }
  
  public A withGatewayIp(String gatewayIp) {
    this.gatewayIp=gatewayIp; return (A) this;
  }
  
  public boolean hasGatewayIp() {
    return this.gatewayIp != null;
  }
  
  public String getId() {
    return this.id;
  }
  
  public A withId(String id) {
    this.id=id; return (A) this;
  }
  
  public boolean hasId() {
    return this.id != null;
  }
  
  public Integer getIpVersion() {
    return this.ipVersion;
  }
  
  public A withIpVersion(Integer ipVersion) {
    this.ipVersion=ipVersion; return (A) this;
  }
  
  public boolean hasIpVersion() {
    return this.ipVersion != null;
  }
  
  public String getIpv6AddressMode() {
    return this.ipv6AddressMode;
  }
  
  public A withIpv6AddressMode(String ipv6AddressMode) {
    this.ipv6AddressMode=ipv6AddressMode; return (A) this;
  }
  
  public boolean hasIpv6AddressMode() {
    return this.ipv6AddressMode != null;
  }
  
  public String getIpv6RaMode() {
    return this.ipv6RaMode;
  }
  
  public A withIpv6RaMode(String ipv6RaMode) {
    this.ipv6RaMode=ipv6RaMode; return (A) this;
  }
  
  public boolean hasIpv6RaMode() {
    return this.ipv6RaMode != null;
  }
  
  public Integer getLimit() {
    return this.limit;
  }
  
  public A withLimit(Integer limit) {
    this.limit=limit; return (A) this;
  }
  
  public boolean hasLimit() {
    return this.limit != null;
  }
  
  public String getMarker() {
    return this.marker;
  }
  
  public A withMarker(String marker) {
    this.marker=marker; return (A) this;
  }
  
  public boolean hasMarker() {
    return this.marker != null;
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public String getNetworkId() {
    return this.networkId;
  }
  
  public A withNetworkId(String networkId) {
    this.networkId=networkId; return (A) this;
  }
  
  public boolean hasNetworkId() {
    return this.networkId != null;
  }
  
  public String getNotTags() {
    return this.notTags;
  }
  
  public A withNotTags(String notTags) {
    this.notTags=notTags; return (A) this;
  }
  
  public boolean hasNotTags() {
    return this.notTags != null;
  }
  
  public String getNotTagsAny() {
    return this.notTagsAny;
  }
  
  public A withNotTagsAny(String notTagsAny) {
    this.notTagsAny=notTagsAny; return (A) this;
  }
  
  public boolean hasNotTagsAny() {
    return this.notTagsAny != null;
  }
  
  public String getProjectId() {
    return this.projectId;
  }
  
  public A withProjectId(String projectId) {
    this.projectId=projectId; return (A) this;
  }
  
  public boolean hasProjectId() {
    return this.projectId != null;
  }
  
  public String getSortDir() {
    return this.sortDir;
  }
  
  public A withSortDir(String sortDir) {
    this.sortDir=sortDir; return (A) this;
  }
  
  public boolean hasSortDir() {
    return this.sortDir != null;
  }
  
  public String getSortKey() {
    return this.sortKey;
  }
  
  public A withSortKey(String sortKey) {
    this.sortKey=sortKey; return (A) this;
  }
  
  public boolean hasSortKey() {
    return this.sortKey != null;
  }
  
  public String getSubnetpoolId() {
    return this.subnetpoolId;
  }
  
  public A withSubnetpoolId(String subnetpoolId) {
    this.subnetpoolId=subnetpoolId; return (A) this;
  }
  
  public boolean hasSubnetpoolId() {
    return this.subnetpoolId != null;
  }
  
  public String getTags() {
    return this.tags;
  }
  
  public A withTags(String tags) {
    this.tags=tags; return (A) this;
  }
  
  public boolean hasTags() {
    return this.tags != null;
  }
  
  public String getTagsAny() {
    return this.tagsAny;
  }
  
  public A withTagsAny(String tagsAny) {
    this.tagsAny=tagsAny; return (A) this;
  }
  
  public boolean hasTagsAny() {
    return this.tagsAny != null;
  }
  
  public String getTenantId() {
    return this.tenantId;
  }
  
  public A withTenantId(String tenantId) {
    this.tenantId=tenantId; return (A) this;
  }
  
  public boolean hasTenantId() {
    return this.tenantId != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubnetFilterFluent that = (SubnetFilterFluent) o;
    if (!java.util.Objects.equals(cidr, that.cidr)) return false;
  
    if (!java.util.Objects.equals(description, that.description)) return false;
  
    if (!java.util.Objects.equals(enableDhcp, that.enableDhcp)) return false;
  
    if (!java.util.Objects.equals(gatewayIp, that.gatewayIp)) return false;
  
    if (!java.util.Objects.equals(id, that.id)) return false;
  
    if (!java.util.Objects.equals(ipVersion, that.ipVersion)) return false;
  
    if (!java.util.Objects.equals(ipv6AddressMode, that.ipv6AddressMode)) return false;
  
    if (!java.util.Objects.equals(ipv6RaMode, that.ipv6RaMode)) return false;
  
    if (!java.util.Objects.equals(limit, that.limit)) return false;
  
    if (!java.util.Objects.equals(marker, that.marker)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(networkId, that.networkId)) return false;
  
    if (!java.util.Objects.equals(notTags, that.notTags)) return false;
  
    if (!java.util.Objects.equals(notTagsAny, that.notTagsAny)) return false;
  
    if (!java.util.Objects.equals(projectId, that.projectId)) return false;
  
    if (!java.util.Objects.equals(sortDir, that.sortDir)) return false;
  
    if (!java.util.Objects.equals(sortKey, that.sortKey)) return false;
  
    if (!java.util.Objects.equals(subnetpoolId, that.subnetpoolId)) return false;
  
    if (!java.util.Objects.equals(tags, that.tags)) return false;
  
    if (!java.util.Objects.equals(tagsAny, that.tagsAny)) return false;
  
    if (!java.util.Objects.equals(tenantId, that.tenantId)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(cidr,  description,  enableDhcp,  gatewayIp,  id,  ipVersion,  ipv6AddressMode,  ipv6RaMode,  limit,  marker,  name,  networkId,  notTags,  notTagsAny,  projectId,  sortDir,  sortKey,  subnetpoolId,  tags,  tagsAny,  tenantId,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cidr != null) { sb.append("cidr:"); sb.append(cidr + ","); }
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (enableDhcp != null) { sb.append("enableDhcp:"); sb.append(enableDhcp + ","); }
    if (gatewayIp != null) { sb.append("gatewayIp:"); sb.append(gatewayIp + ","); }
    if (id != null) { sb.append("id:"); sb.append(id + ","); }
    if (ipVersion != null) { sb.append("ipVersion:"); sb.append(ipVersion + ","); }
    if (ipv6AddressMode != null) { sb.append("ipv6AddressMode:"); sb.append(ipv6AddressMode + ","); }
    if (ipv6RaMode != null) { sb.append("ipv6RaMode:"); sb.append(ipv6RaMode + ","); }
    if (limit != null) { sb.append("limit:"); sb.append(limit + ","); }
    if (marker != null) { sb.append("marker:"); sb.append(marker + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (networkId != null) { sb.append("networkId:"); sb.append(networkId + ","); }
    if (notTags != null) { sb.append("notTags:"); sb.append(notTags + ","); }
    if (notTagsAny != null) { sb.append("notTagsAny:"); sb.append(notTagsAny + ","); }
    if (projectId != null) { sb.append("projectId:"); sb.append(projectId + ","); }
    if (sortDir != null) { sb.append("sortDir:"); sb.append(sortDir + ","); }
    if (sortKey != null) { sb.append("sortKey:"); sb.append(sortKey + ","); }
    if (subnetpoolId != null) { sb.append("subnetpoolId:"); sb.append(subnetpoolId + ","); }
    if (tags != null) { sb.append("tags:"); sb.append(tags + ","); }
    if (tagsAny != null) { sb.append("tagsAny:"); sb.append(tagsAny + ","); }
    if (tenantId != null) { sb.append("tenantId:"); sb.append(tenantId + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withEnableDhcp() {
    return withEnableDhcp(true);
  }
  

}
